==> tutti-ui-swing-2.3.3-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/ExportProtocolCaracteristicAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: ExportProtocolCaracteristicAction.java 845 2013-04-22 06:53:55Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.3.3/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/ExportProtocolCaracteristicAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Preconditions;
import fr.ifremer.tutti.TuttiIOUtil;
import fr.ifremer.tutti.persistence.entities.protocol.TuttiProtocol;
import fr.ifremer.tutti.service.protocol.TuttiProtocolImportExportService;
import fr.ifremer.tutti.ui.swing.util.TuttiUIUtil;
import fr.ifremer.tutti.ui.swing.util.action.AbstractTuttiAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.io.File;

import static org.nuiton.i18n.I18n._;

/**
 * To import protocol caracteristics.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ExportProtocolCaracteristicAction extends AbstractTuttiAction<EditProtocolUIModel, EditProtocolUI, EditProtocolUIHandler> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ExportProtocolCaracteristicAction.class);

    private File file;

    public ExportProtocolCaracteristicAction(EditProtocolUIHandler handler) {
        super(handler, true);
    }

    @Override
    protected boolean prepareAction() throws Exception {

        boolean doAction = super.prepareAction();

        if (doAction) {

            // choose file to export
            file = TuttiUIUtil.saveFile(
                    "tuttiProtocol-" + getModel().getName() + "-caracteristics.csv",
                    getContext().getMainUI(),
                    _("tutti.editProtocol.title.choose.caracteristicExportFile"),
                    _("tutti.editProtocol.action.chooseProtocolCaracteristicFile"),
                    "^.*\\.csv", _("tutti.common.file.csv")
            );
            if (file == null) {

                // user cancel
                doAction = false;
            } else {

                // add extension if missing
                file = TuttiIOUtil.addExtensionIfMissing(file, ".csv");

                // ask user to confirm overwrite.
                doAction = getHandler().askOverwriteFile(file);
            }
        }
        return doAction;
    }

    @Override
    protected void releaseAction() {
        file = null;
        super.releaseAction();
    }

    @Override
    protected void doAction() throws Exception {
        Preconditions.checkNotNull(file);
        if (log.isInfoEnabled()) {
            log.info("Will export protocol caracteristic to file: " + file);
        }

        // bind to a protocol
        TuttiProtocol protocol = getModel().toBean();

        // export protocol caracteristics
        TuttiProtocolImportExportService service =
                getContext().getTuttiProtocolImportExportService();

        service.exportProtocolCaracteristic(file,
                                            protocol,
                                            getModel().getAllCaracteristic());

        sendMessage(_("tutti.flash.info.caractristic.exported.from.protocol",
                      file));
    }
}

==> tutti-ui-swing-2.4-sources.jar: fr/ifremer/tutti/ui/swing/content/protocol/ExportProtocolCaracteristicAction.java <==
package fr.ifremer.tutti.ui.swing.content.protocol;

/*
 * #%L
 * Tutti :: UI
 * $Id: ExportProtocolCaracteristicAction.java 1170 2013-09-13 16:21:34Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.4/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/protocol/ExportProtocolCaracteristicAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import com.google.common.base.Preconditions;
import fr.ifremer.tutti.persistence.entities.protocol.TuttiProtocol;
import fr.ifremer.tutti.service.protocol.TuttiProtocolImportExportService;
import fr.ifremer.tutti.ui.swing.util.action.AbstractTuttiAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import java.io.File;

import static org.nuiton.i18n.I18n._;

/**
 * To import protocol caracteristics.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ExportProtocolCaracteristicAction extends AbstractTuttiAction<EditProtocolUIModel, EditProtocolUI, EditProtocolUIHandler> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ExportProtocolCaracteristicAction.class);

    private File file;

    public ExportProtocolCaracteristicAction(EditProtocolUIHandler handler) {
        super(handler, true);
    }

    @Override
    public boolean prepareAction() throws Exception {

        boolean doAction = super.prepareAction();

        if (doAction) {

            // choose file to export
            file = saveFile(
                    "tuttiProtocol-" + getModel().getName() + "-caracteristics",
                    "csv",
                    _("tutti.editProtocol.title.choose.caracteristicExportFile"),
                    _("tutti.editProtocol.action.chooseProtocolCaracteristicFile"),
                    "^.*\\.csv", _("tutti.common.file.csv")
            );
            doAction = file != null;
        }
        return doAction;
    }

    @Override
    public void releaseAction() {
        file = null;
        super.releaseAction();
    }

    @Override
    public void doAction() throws Exception {
        Preconditions.checkNotNull(file);
        if (log.isInfoEnabled()) {
            log.info("Will export protocol caracteristic to file: " + file);
        }

        // bind to a protocol
        TuttiProtocol protocol = getModel().toBean();

        // export protocol caracteristics
        TuttiProtocolImportExportService service =
                getContext().getTuttiProtocolImportExportService();

        service.exportProtocolCaracteristic(file,
                                            protocol,
                                            getModel().getAllCaracteristic());

        sendMessage(_("tutti.flash.info.caractristic.exported.from.protocol",
                      file));
    }
}
